from __future__ import annotations

from typing import Any, Optional

def summary(net: Any, input_size: Optional[Any] = ..., dtypes: Optional[Any] = ..., input: Optional[Any] = ...): ...
def summary_string(
    model: Any, input_size: Optional[Any] = ..., dtypes: Optional[Any] = ..., input: Optional[Any] = ...
): ...
