from __future__ import annotations

from typing import Any

class PSDispatcher:
    def __init__(self, pserver_endpoints: Any) -> None: ...
    @property
    def eps(self): ...
    def reset(self) -> None: ...
    def dispatch(self, varlist: Any) -> None: ...

class HashName(PSDispatcher):
    def __init__(self, pserver_endpoints: Any) -> None: ...
    def dispatch(self, varlist: Any): ...

class RoundRobin(PSDispatcher):
    def __init__(self, pserver_endpoints: Any) -> None: ...
    def dispatch(self, varlist: Any): ...
