from __future__ import annotations

from typing import Any, Optional

def segment_sum(data: Any, segment_ids: Any, name: Optional[Any] = ...): ...
def segment_mean(data: Any, segment_ids: Any, name: Optional[Any] = ...): ...
def segment_min(data: Any, segment_ids: Any, name: Optional[Any] = ...): ...
def segment_max(data: Any, segment_ids: Any, name: Optional[Any] = ...): ...
