from __future__ import annotations

from typing import Any

def log(ctx: Any) -> None: ...
def process_args(ctx: Any) -> None: ...
def collective_compatible(ctx: Any) -> None: ...
def rewrite_host_ip(ctx: Any) -> None: ...

enabled_plugins: Any
