from __future__ import annotations

from ...fluid.contrib.layers import sparse_embedding as sparse_embedding
from ...fluid.input import embedding as embedding
from ...fluid.layers import batch_norm as batch_norm
from ...fluid.layers import bilinear_tensor_product as bilinear_tensor_product
from ...fluid.layers import case as case
from ...fluid.layers import cond as cond
from ...fluid.layers import conv2d as conv2d
from ...fluid.layers import conv2d_transpose as conv2d_transpose
from ...fluid.layers import conv3d as conv3d
from ...fluid.layers import conv3d_transpose as conv3d_transpose
from ...fluid.layers import crf_decoding as crf_decoding
from ...fluid.layers import data_norm as data_norm
from ...fluid.layers import group_norm as group_norm
from ...fluid.layers import instance_norm as instance_norm
from ...fluid.layers import layer_norm as layer_norm
from ...fluid.layers import multi_box_head as multi_box_head
from ...fluid.layers import nce as nce
from ...fluid.layers import prelu as prelu
from ...fluid.layers import py_func as py_func
from ...fluid.layers import row_conv as row_conv
from ...fluid.layers import spectral_norm as spectral_norm
from ...fluid.layers import switch_case as switch_case
from ...fluid.layers import while_loop as while_loop
from ...fluid.layers.sequence_lod import sequence_concat as sequence_concat
from ...fluid.layers.sequence_lod import sequence_conv as sequence_conv
from ...fluid.layers.sequence_lod import sequence_enumerate as sequence_enumerate
from ...fluid.layers.sequence_lod import sequence_expand as sequence_expand
from ...fluid.layers.sequence_lod import sequence_expand_as as sequence_expand_as
from ...fluid.layers.sequence_lod import sequence_first_step as sequence_first_step
from ...fluid.layers.sequence_lod import sequence_last_step as sequence_last_step
from ...fluid.layers.sequence_lod import sequence_pad as sequence_pad
from ...fluid.layers.sequence_lod import sequence_pool as sequence_pool
from ...fluid.layers.sequence_lod import sequence_reshape as sequence_reshape
from ...fluid.layers.sequence_lod import sequence_reverse as sequence_reverse
from ...fluid.layers.sequence_lod import sequence_scatter as sequence_scatter
from ...fluid.layers.sequence_lod import sequence_slice as sequence_slice
from ...fluid.layers.sequence_lod import sequence_softmax as sequence_softmax
from ...fluid.layers.sequence_lod import sequence_unpad as sequence_unpad
from .common import deform_conv2d as deform_conv2d
from .common import fc as fc
