from __future__ import annotations

from typing import Any

def get_cloud_cluster(args_node_ips: Any, device_mode: Any, devices_per_proc: Any, args_port: int = ...): ...
def use_paddlecloud(): ...
def get_trainers_num(): ...
