from __future__ import annotations

from typing import Any

class Command:
    etcd: Any = ...
    prefix: Any = ...
    node_prefix: Any = ...
    np_path: Any = ...
    def __init__(self, server: Any, name: Any) -> None: ...
    def set_np(self, np: Any) -> None: ...
    def scale_np(self, np: Any): ...
    def clean(self) -> None: ...
    def close(self) -> None: ...
