from __future__ import annotations

from typing import Any

from paddle.distributed.fleet.utils.fs import FS

class HDFSClient(FS):
    pre_commands: Any = ...
    def __init__(self, hadoop_home: Any, configs: Any, time_out: Any = ..., sleep_inter: int = ...) -> None: ...
    def list_dirs(self, fs_path: Any): ...
    def ls_dir(self, fs_path: Any): ...
    def is_dir(self, fs_path: Any): ...
    def is_file(self, fs_path: Any): ...
    def is_exist(self, fs_path: Any): ...
    def upload(self, local_path: Any, fs_path: Any): ...
    def download(self, fs_path: Any, local_path: Any): ...
    def mkdirs(self, fs_path: Any) -> None: ...
    def mv(self, fs_src_path: Any, fs_dst_path: Any, overwrite: bool = ..., test_exists: bool = ...): ...
    def delete(self, fs_path: Any): ...
    def touch(self, fs_path: Any, exist_ok: bool = ...): ...
    def need_upload_download(self): ...
