from __future__ import annotations

from typing import Any, Optional

def parameters_to_vector(parameters: Any, name: Optional[Any] = ...): ...
def vector_to_parameters(vec: Any, parameters: Any, name: Optional[Any] = ...): ...
