from __future__ import annotations

from typing import Any

URL_PREFIX: str
CIFAR10_URL: Any
CIFAR10_MD5: str
CIFAR100_URL: Any
CIFAR100_MD5: str

def reader_creator(filename: Any, sub_name: Any, cycle: bool = ...): ...
def train100(): ...
def test100(): ...
def train10(cycle: bool = ...): ...
def test10(cycle: bool = ...): ...
def fetch() -> None: ...
