from __future__ import annotations

from typing import Any, Optional

def graph_send_recv(
    x: Any,
    src_index: Any,
    dst_index: Any,
    pool_type: str = ...,
    out_size: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
