from __future__ import annotations

from typing import Any

from paddle.fluid import core as core

def delete_ops(block: Any, ops: Any) -> None: ...
def find_op_by_input_arg(block: Any, arg_name: Any): ...
def find_op_by_output_arg(block: Any, arg_name: Any, reverse: bool = ...): ...
