from __future__ import annotations

from typing import Any, Optional

from paddle.distributed.fleet.launch_utils import logger as logger

def get_cloud_cluster(rank_table_file: Optional[Any] = ..., device_mode: Any = ..., start_port: int = ...): ...
