from __future__ import annotations

from typing import Any, Optional

def sum(input: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def max(input: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def min(input: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def auc(stat_pos: Any, stat_neg: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def mae(abserr: Any, total_ins_num: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def rmse(sqrerr: Any, total_ins_num: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def mse(sqrerr: Any, total_ins_num: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def acc(correct: Any, total: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
