from __future__ import annotations

from typing import Any

from .device import Device as Device

class Node:
    device: Any = ...
    ip: Any = ...
    free_ports: Any = ...
    def __init__(self) -> None: ...
    hostname: Any = ...
    def get_host_ip(self): ...
    def get_free_ports(self, n: int = ...): ...
    def get_ports_occupied(self): ...
    def get_free_port(self): ...
    @classmethod
    def is_server_ready(cls, ip: Any, port: Any): ...
