from __future__ import annotations

from typing import Any

from paddle.distribution import exponential_family

class Beta(exponential_family.ExponentialFamily):
    def __init__(self, alpha: Any, beta: Any) -> None: ...
    @property
    def mean(self): ...
    @property
    def variance(self): ...
    def prob(self, value: Any): ...
    def log_prob(self, value: Any): ...
    def sample(self, shape: Any = ...): ...
    def entropy(self): ...
