from __future__ import annotations

from typing import Any

def gloo_init_parallel_env(rank_id: Any, rank_num: Any, server_endpoint: Any) -> None: ...
def gloo_barrier() -> None: ...
def gloo_release() -> None: ...
