from __future__ import annotations

from ...fluid.contrib.sparsity import calculate_density as calculate_density
from ...fluid.contrib.sparsity import decorate as decorate
from ...fluid.contrib.sparsity import prune_model as prune_model
from ...fluid.contrib.sparsity import reset_excluded_layers as reset_excluded_layers
from ...fluid.contrib.sparsity import set_excluded_layers as set_excluded_layers
