from __future__ import annotations

from typing import Any

class LayerInfo:
    layer: Any = ...
    input_names: Any = ...
    weight_names: Any = ...
    output_names: Any = ...
    def __init__(self, layer: Any, input_names: Any, weight_names: Any, output_names: Any) -> None: ...

class PTQRegistry:
    supported_layers_map: Any = ...
    registered_layers_map: Any = ...
    is_inited: bool = ...
    def __init__(self) -> None: ...
    @classmethod
    def is_supported_layer(cls, layer: Any): ...
    @classmethod
    def is_registered_layer(cls, layer: Any): ...
    @classmethod
    def is_simulated_quant_layer(cls, layer: Any): ...
    @classmethod
    def layer_info(cls, layer: Any): ...
