from __future__ import annotations

from typing import Any

class Event:
    kind: Any = ...
    message: Any = ...
    fatal: Any = ...
    def __init__(self, kind: str = ..., message: str = ..., fatal: bool = ...) -> None: ...
