from __future__ import annotations

from typing import Any, Optional

URL: str
MD5: str

class DataType:
    NGRAM: int = ...
    SEQ: int = ...

def word_count(f: Any, word_freq: Optional[Any] = ...): ...
def build_dict(min_word_freq: int = ...): ...
def reader_creator(filename: Any, word_idx: Any, n: Any, data_type: Any): ...
def train(word_idx: Any, n: Any, data_type: Any = ...): ...
def test(word_idx: Any, n: Any, data_type: Any = ...): ...
def fetch() -> None: ...
