from __future__ import annotations

# Because pyright thinks that `paddle.vision.alexnet` is a module,
# so rename `alexnet.pyi` to `_alexnet.pyi`. `_googlenet.pyi` is same.
from ._alexnet import AlexNet as AlexNet
from ._alexnet import alexnet as alexnet
from ._googlenet import GoogLeNet as GoogLeNet
from ._googlenet import googlenet as googlenet
from .densenet import DenseNet as DenseNet
from .densenet import densenet121 as densenet121
from .densenet import densenet161 as densenet161
from .densenet import densenet169 as densenet169
from .densenet import densenet201 as densenet201
from .densenet import densenet264 as densenet264
from .inceptionv3 import InceptionV3 as InceptionV3
from .inceptionv3 import inception_v3 as inception_v3
from .lenet import LeNet as LeNet
from .mobilenetv1 import MobileNetV1 as MobileNetV1
from .mobilenetv1 import mobilenet_v1 as mobilenet_v1
from .mobilenetv2 import MobileNetV2 as MobileNetV2
from .mobilenetv2 import mobilenet_v2 as mobilenet_v2
from .mobilenetv3 import MobileNetV3Large as MobileNetV3Large
from .mobilenetv3 import MobileNetV3Small as MobileNetV3Small
from .mobilenetv3 import mobilenet_v3_large as mobilenet_v3_large
from .mobilenetv3 import mobilenet_v3_small as mobilenet_v3_small
from .resnet import ResNet as ResNet
from .resnet import resnet18 as resnet18
from .resnet import resnet34 as resnet34
from .resnet import resnet50 as resnet50
from .resnet import resnet101 as resnet101
from .resnet import resnet152 as resnet152
from .resnet import resnext50_32x4d as resnext50_32x4d
from .resnet import resnext50_64x4d as resnext50_64x4d
from .resnet import resnext101_32x4d as resnext101_32x4d
from .resnet import resnext101_64x4d as resnext101_64x4d
from .resnet import resnext152_32x4d as resnext152_32x4d
from .resnet import resnext152_64x4d as resnext152_64x4d
from .resnet import wide_resnet50_2 as wide_resnet50_2
from .resnet import wide_resnet101_2 as wide_resnet101_2
from .shufflenetv2 import ShuffleNetV2 as ShuffleNetV2
from .shufflenetv2 import shufflenet_v2_swish as shufflenet_v2_swish
from .shufflenetv2 import shufflenet_v2_x0_5 as shufflenet_v2_x0_5
from .shufflenetv2 import shufflenet_v2_x0_25 as shufflenet_v2_x0_25
from .shufflenetv2 import shufflenet_v2_x0_33 as shufflenet_v2_x0_33
from .shufflenetv2 import shufflenet_v2_x1_0 as shufflenet_v2_x1_0
from .shufflenetv2 import shufflenet_v2_x1_5 as shufflenet_v2_x1_5
from .shufflenetv2 import shufflenet_v2_x2_0 as shufflenet_v2_x2_0
from .squeezenet import SqueezeNet as SqueezeNet
from .squeezenet import squeezenet1_0 as squeezenet1_0
from .squeezenet import squeezenet1_1 as squeezenet1_1
from .vgg import VGG as VGG
from .vgg import vgg11 as vgg11
from .vgg import vgg13 as vgg13
from .vgg import vgg16 as vgg16
from .vgg import vgg19 as vgg19
