from __future__ import annotations

from typing import Any

def sum_ranges(ranges: Any): ...
def merge_self_ranges(src_ranges: Any, is_sorted: bool = ...): ...
def merge_ranges(range_list1: Any, range_list2: Any, is_sorted: bool = ...): ...
def intersection_ranges(range_list1: Any, range_list2: Any, is_sorted: bool = ...): ...
def subtract_ranges(range_list1: Any, range_list2: Any, is_sorted: bool = ...): ...
