from __future__ import annotations

from typing import Any, Optional

def normalize(img: Any, mean: Any, std: Any, data_format: str = ...): ...
def to_grayscale(img: Any, num_output_channels: int = ..., data_format: str = ...): ...
def rotate(
    img: Any,
    angle: Any,
    interpolation: str = ...,
    expand: bool = ...,
    center: Optional[Any] = ...,
    fill: Optional[Any] = ...,
    data_format: str = ...,
): ...
def vflip(img: Any, data_format: str = ...): ...
def hflip(img: Any, data_format: str = ...): ...
def crop(img: Any, top: Any, left: Any, height: Any, width: Any, data_format: str = ...): ...
def center_crop(img: Any, output_size: Any, data_format: str = ...): ...
def pad(img: Any, padding: Any, fill: int = ..., padding_mode: str = ..., data_format: str = ...): ...
def resize(img: Any, size: Any, interpolation: str = ..., data_format: str = ...): ...
