from __future__ import annotations

from typing import Any, Optional

from ..fluid import layers as layers

def array_length(array: Any): ...
def array_read(array: Any, i: Any): ...
def array_write(x: Any, i: Any, array: Optional[Any] = ...): ...
def create_array(dtype: Any, initialized_list: Optional[Any] = ...): ...
