from __future__ import annotations

from typing import Any, Optional

def fp16_guard() -> None: ...
def cast_model_to_fp16(program: Any, amp_lists: Optional[Any] = ..., use_fp16_guard: bool = ...): ...
def cast_parameters_to_fp16(
    place: Any, program: Any, scope: Optional[Any] = ..., to_fp16_var_names: Optional[Any] = ...
) -> None: ...
