from __future__ import annotations

from typing import Any

from paddle.utils import gast

cmpop_type_to_str: Any

def cmpop_node_to_str(node: Any): ...

class LogicalTransformer(gast.NodeTransformer):
    wrapper_root: Any = ...
    root: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self): ...
    def visit_UnaryOp(self, node: Any): ...
    def visit_Compare(self, node: Any): ...
    def visit_BoolOp(self, node: Any): ...
