from __future__ import annotations

from typing import Any, Optional

class QuantInt8MkldnnPass:
    def __init__(self, _scope: Optional[Any] = ..., _place: Optional[Any] = ...) -> None: ...
    def apply(self, graph: Any): ...
