from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

DATA_URL: str
DATA_MD5: str
TOTAL_EN_WORDS: int
TOTAL_DE_WORDS: int
START_MARK: str
END_MARK: str
UNK_MARK: str

class WMT16(Dataset):
    mode: Any = ...
    data_file: Any = ...
    lang: Any = ...
    src_dict_size: Any = ...
    trg_dict_size: Any = ...
    src_dict: Any = ...
    trg_dict: Any = ...
    data: Any = ...
    def __init__(
        self,
        data_file: Optional[Any] = ...,
        mode: str = ...,
        src_dict_size: int = ...,
        trg_dict_size: int = ...,
        lang: str = ...,
        download: bool = ...,
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...
    def get_dict(self, lang: Any, reverse: bool = ...): ...
