from __future__ import annotations

from paddle.autograd.functional import Hessian as Hessian
from paddle.autograd.functional import Jacobian as Jacobian
from paddle.autograd.functional import jvp as jvp
from paddle.autograd.functional import vjp as vjp
