from __future__ import annotations

from paddle.reader.decorator import ComposeNotAligned as ComposeNotAligned
from paddle.reader.decorator import buffered as buffered
from paddle.reader.decorator import cache as cache
from paddle.reader.decorator import chain as chain
from paddle.reader.decorator import compose as compose
from paddle.reader.decorator import firstn as firstn
from paddle.reader.decorator import map_readers as map_readers
from paddle.reader.decorator import multiprocess_reader as multiprocess_reader
from paddle.reader.decorator import shuffle as shuffle
from paddle.reader.decorator import xmap_readers as xmap_readers
