from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

URL: str
MD5: str
feature_names: Any

class UCIHousing(Dataset):
    mode: Any = ...
    data_file: Any = ...
    dtype: Any = ...
    def __init__(self, data_file: Optional[Any] = ..., mode: str = ..., download: bool = ...) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...
