from __future__ import annotations

from typing import Any

class CostModel:
    def __init__(self) -> None: ...
    def build_program(self): ...
    def profile_measure(
        self, startup_program: Any, main_program: Any, device: str = ..., fetch_cost_list: Any = ...
    ) -> None: ...
    def static_cost_data(self): ...
    def get_static_op_time(self, op_name: Any, forward: bool = ..., dtype: str = ...): ...
