from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

URL: str
MD5: str

class Imikolov(Dataset):
    data_type: Any = ...
    mode: Any = ...
    window_size: Any = ...
    min_word_freq: Any = ...
    data_file: Any = ...
    word_idx: Any = ...
    def __init__(
        self,
        data_file: Optional[Any] = ...,
        data_type: str = ...,
        window_size: int = ...,
        mode: str = ...,
        min_word_freq: int = ...,
        download: bool = ...,
    ) -> None: ...
    def word_count(self, f: Any, word_freq: Optional[Any] = ...): ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...
