from __future__ import annotations

from typing import Any

from .meta_optimizer_base import MetaOptimizerBase as MetaOptimizerBase

class FP16AllReduceOptimizer(MetaOptimizerBase):
    inner_opt: Any = ...
    meta_optimizers_white_list: Any = ...
    meta_optimizers_black_list: Any = ...
    def __init__(self, optimizer: Any) -> None: ...
    @staticmethod
    def fp16_compression(param_and_grads: Any): ...
    def apply_optimize(self, loss: Any, startup_program: Any, params_grads: Any): ...
