from __future__ import annotations

import unittest
from typing import Any

def conv_net(img: Any, label: Any): ...

class TestMKLDNNTransformBasedFreezePass(unittest.TestCase):
    quantizable_op_and_inputs: Any = ...
    def setUp(self) -> None: ...
    def check_program(self, program: Any) -> None: ...
    def isinteger(self, x: Any): ...
    def build_program(self, main: Any, startup: Any, is_test: Any, seed: Any): ...
    def mkldnn_based_freeze_graph(
        self,
        use_cuda: Any,
        seed: Any,
        activation_quant_type: Any,
        weight_quant_type: str = ...,
        quant_perf: bool = ...,
        for_ci: bool = ...,
    ) -> None: ...
    def test_mkldnn_graph_cpu_static(self) -> None: ...
