from __future__ import annotations

import unittest
from typing import Any

def reader_creator_10(dur: Any): ...

class TestMap(unittest.TestCase):
    def test_map(self): ...

class TestBuffered(unittest.TestCase):
    def test_read(self) -> None: ...
    def test_buffering(self) -> None: ...

class TestCompose(unittest.TestCase):
    def test_compse(self) -> None: ...
    def test_compose_not_aligned(self) -> None: ...
    def test_compose_not_aligned_no_check(self) -> None: ...

class TestChain(unittest.TestCase):
    def test_chain(self) -> None: ...

class TestShuffle(unittest.TestCase):
    def test_shuffle(self) -> None: ...

class TestXmap(unittest.TestCase):
    def test_xmap(self): ...

class TestMultiProcessReader(unittest.TestCase):
    samples: Any = ...
    reader0: Any = ...
    reader1: Any = ...
    reader2: Any = ...
    def setup(self) -> None: ...
    def reader_test(self, use_pipe: Any) -> None: ...
    def test_distributed_batch_reader(self) -> None: ...
