from __future__ import annotations

from typing import Any

URL: str
MD5: str
feature_names: Any
UCI_TRAIN_DATA: Any
UCI_TEST_DATA: Any
FLUID_URL_MODEL: str
FLUID_MD5_MODEL: str

def feature_range(maximums: Any, minimums: Any) -> None: ...
def load_data(filename: Any, feature_num: int = ..., ratio: float = ...) -> None: ...
def train(): ...
def test(): ...
def fluid_model(): ...
def predict_reader(): ...
def fetch() -> None: ...
