from __future__ import annotations

from typing import Any

from ..utils.fs import FS as FS
from ..utils.fs import HDFSClient as HDFSClient
from ..utils.fs import LocalFS as LocalFS

class UtilFactory: ...

class UtilBase:
    role_maker: Any = ...
    dist_strategy: Any = ...
    def __init__(self) -> None: ...
    def all_reduce(self, input: Any, mode: str = ..., comm_world: str = ...): ...
    def barrier(self, comm_world: str = ...) -> None: ...
    def all_gather(self, input: Any, comm_world: str = ...): ...
    def get_file_shard(self, files: Any): ...
    def print_on_rank(self, message: Any, rank_id: Any) -> None: ...
