from __future__ import annotations

from typing import Any

URL: str
MD5: str

def tokenize(pattern: Any) -> None: ...
def build_dict(pattern: Any, cutoff: Any): ...
def reader_creator(pos_pattern: Any, neg_pattern: Any, word_idx: Any): ...
def train(word_idx: Any): ...
def test(word_idx: Any): ...
def word_dict(): ...
def fetch() -> None: ...
