from __future__ import annotations

import unittest
from typing import Any

def conv_net(img: Any, label: Any): ...

class TestQuantizationScalePass(unittest.TestCase):
    def quantization_scale(
        self, use_cuda: Any, seed: Any, activation_quant_type: Any, weight_quant_type: str = ..., for_ci: bool = ...
    ): ...
    def test_quant_scale_cuda(self) -> None: ...
    def test_quant_scale_cpu(self) -> None: ...
