from __future__ import annotations

from typing import Any, Optional

def generate_layer_fn(op_type: Any): ...
def generate_activation_fn(op_type: Any): ...
def generate_inplace_fn(inplace_op_type: Any): ...
def autodoc(comment: str = ...): ...
def templatedoc(op_type: Optional[Any] = ...): ...
