from __future__ import annotations

from typing import Any, Optional

def accuracy(input: Any, label: Any, k: int = ..., correct: Optional[Any] = ..., total: Optional[Any] = ...): ...
def auc(
    input: Any, label: Any, curve: str = ..., num_thresholds: Any = ..., topk: int = ..., slide_steps: int = ...
): ...
