from __future__ import annotations

from typing import Any

class TrainerFactory:
    def __init__(self) -> None: ...

class FetchHandlerMonitor:
    fetch_instance: Any = ...
    fetch_thread: Any = ...
    running_lock: Any = ...
    running: bool = ...
    def __init__(self, scope: Any, handler: Any) -> None: ...
    def handler_launch_func(self, scope: Any, handler: Any) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
