from __future__ import annotations

from typing import Any

def get_cur_scope(): ...
def enter_local_scope() -> None: ...
def leave_local_scope() -> None: ...
def var(name: Any): ...
def find_var(name: Any): ...
def scoped_function(func: Any) -> None: ...
