from __future__ import annotations

from typing import Any, Optional

from .static_flops import Table as Table
from .static_flops import static_flops as static_flops

def flops(net: Any, input_size: Any, custom_ops: Optional[Any] = ..., print_detail: bool = ...): ...
def count_convNd(m: Any, x: Any, y: Any) -> None: ...
def count_leaky_relu(m: Any, x: Any, y: Any) -> None: ...
def count_bn(m: Any, x: Any, y: Any) -> None: ...
def count_linear(m: Any, x: Any, y: Any) -> None: ...
def count_avgpool(m: Any, x: Any, y: Any) -> None: ...
def count_adap_avgpool(m: Any, x: Any, y: Any) -> None: ...
def count_zero_ops(m: Any, x: Any, y: Any) -> None: ...
def count_parameters(m: Any, x: Any, y: Any) -> None: ...
def count_io_info(m: Any, x: Any, y: Any) -> None: ...

register_hooks: Any

def dynamic_flops(model: Any, inputs: Any, custom_ops: Optional[Any] = ..., print_detail: bool = ...): ...
