from __future__ import annotations

from typing import Any, Optional

class DistributedInfer:
    origin_main_program: Any = ...
    origin_startup_program: Any = ...
    sparse_table_maps: Any = ...
    def __init__(self, main_program: Optional[Any] = ..., startup_program: Optional[Any] = ...) -> None: ...
    def init_distributed_infer_env(
        self, exe: Any, loss: Any, role_maker: Optional[Any] = ..., dirname: Optional[Any] = ...
    ) -> None: ...
    def get_dist_infer_program(self): ...
