from __future__ import annotations

from typing import Any, Optional

def load_program(model_filename: Any, is_text: bool = ...): ...
def save_program(program: Any, model_filename: str = ..., is_text: bool = ...) -> None: ...
def check_pruned_program_vars(train_prog: Any, pruned_prog: Any): ...
def graphviz(block: Any, output_dir: str = ..., filename: str = ...) -> None: ...
def program_type_trans(prog_dir: Any, prog_fn: Any, is_text: Any): ...
def check_saved_vars_try_dump(
    dump_dir: Any,
    dump_prog_fn: Any,
    is_text_dump_program: Any,
    feed_config: Any,
    fetch_config: Any,
    batch_size: int = ...,
    save_filename: Optional[Any] = ...,
): ...
def parse_program(program: Any, output_dir: Any) -> None: ...
