from __future__ import annotations

from collections import OrderedDict as OrderedDict
from typing import Any

from .log_util import logger as logger

def broadcast_input_data(hcg: Any, *inputs: Any, **kwargs: Any): ...
def broadcast_mp_parameters(model: Any, hcg: Any) -> None: ...
def broadcast_dp_parameters(model: Any, hcg: Any) -> None: ...
def fused_allreduce_gradients(parameter_list: Any, hcg: Any) -> None: ...
def sharding_reduce_gradients(parameter_list: Any, hcg: Any) -> None: ...
def broadcast_sharding_parameters(model: Any, hcg: Any) -> None: ...
