from __future__ import annotations

from .conll05 import Conll05st as Conll05st
from .imdb import Imdb as Imdb
from .imikolov import Imikolov as Imikolov
from .movielens import Movielens as Movielens
from .uci_housing import UCIHousing as UCIHousing
from .wmt14 import WMT14 as WMT14
from .wmt16 import WMT16 as WMT16
