from __future__ import annotations

from typing import Any

class GradientClipHelper:
    mp_ring_id: Any = ...
    def __init__(self, mp_ring_id: Any) -> None: ...
    def prune_gradient_clip(self, block: Any, shard: Any, ring_ids: Any) -> None: ...
    def sync_global_norm(self, block: Any, ring_ids: Any, mp_rank: Any) -> None: ...
