from __future__ import annotations

from typing import Any

class Fleet:
    instance_: Any = ...
    fleet_: Any = ...
    def __init__(self) -> None: ...
    def stop(self) -> None: ...
    dist_desc_str_: Any = ...
    dist_desc_: Any = ...
    def init_pserver(self, opt_info: Any) -> None: ...
    def init_worker(self, opt_info: Any) -> None: ...
    def init_pserver_model(self) -> None: ...
    def save_pserver_model(self, save_path: Any) -> None: ...
