from __future__ import annotations

from typing import Any

from paddle.utils import gast

class GradTransformer(gast.NodeTransformer):
    wrapper_root: Any = ...
    root: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self) -> None: ...
    def visit_Call(self, node: Any): ...

def is_grad_api_node(node: Any): ...
