from __future__ import annotations

from typing import Any

class Index:
    def __init__(self, name: Any) -> None: ...

class TreeIndex(Index):
    def __init__(self, name: Any, path: Any) -> None: ...
    def height(self): ...
    def branch(self): ...
    def total_node_nums(self): ...
    def emb_size(self): ...
    def get_all_leafs(self): ...
    def get_nodes(self, codes: Any): ...
    def get_layer_codes(self, level: Any): ...
    def get_travel_codes(self, id: Any, start_level: int = ...): ...
    def get_ancestor_codes(self, ids: Any, level: Any): ...
    def get_children_codes(self, ancestor: Any, level: Any): ...
    def get_travel_path(self, child: Any, ancestor: Any): ...
    def get_pi_relation(self, ids: Any, level: Any): ...
    def init_layerwise_sampler(
        self, layer_sample_counts: Any, start_sample_layer: int = ..., seed: int = ...
    ) -> None: ...
    def layerwise_sample(self, user_input: Any, index_input: Any, with_hierarchy: bool = ...): ...
