from __future__ import annotations

from typing import Any, Optional

def softshrink(x: Any, alpha: Optional[Any] = ...): ...
def hard_shrink(x: Any, threshold: Optional[Any] = ...): ...
def cumsum(x: Any, axis: Optional[Any] = ..., exclusive: Optional[Any] = ..., reverse: Optional[Any] = ...): ...
def thresholded_relu(x: Any, threshold: Optional[Any] = ...): ...
def gelu(x: Any, approximate: bool = ...): ...
def erf(x: Any, name: Optional[Any] = ...): ...
