from __future__ import annotations

from typing import Any, Optional

interpreter: Any
import_cv2_proc: Any
out: Any
err: Any
retcode: Any
cv2: Any

def batch_images_from_tar(data_file: Any, dataset_name: Any, img2label: Any, num_per_batch: int = ...): ...
def load_image_bytes(bytes: Any, is_color: bool = ...): ...
def load_image(file: Any, is_color: bool = ...): ...
def resize_short(im: Any, size: Any): ...
def to_chw(im: Any, order: Any = ...): ...
def center_crop(im: Any, size: Any, is_color: bool = ...): ...
def random_crop(im: Any, size: Any, is_color: bool = ...): ...
def left_right_flip(im: Any, is_color: bool = ...): ...
def simple_transform(
    im: Any, resize_size: Any, crop_size: Any, is_train: Any, is_color: bool = ..., mean: Optional[Any] = ...
): ...
def load_and_transform(
    filename: Any, resize_size: Any, crop_size: Any, is_train: Any, is_color: bool = ..., mean: Optional[Any] = ...
): ...
