from __future__ import annotations

from typing import Any, Optional

class tqdm:
    total: Any = ...
    n: int = ...
    def __init__(self, total: Optional[Any] = ...) -> None: ...
    def update(self, n: Any) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None: ...

def get_weights_path_from_url(url: Any, md5sum: Optional[Any] = ...): ...
