from __future__ import annotations

from typing import Any, Optional

def set_resnet_unit_attrs(resnet_unit: Any, has_shortcut: Any) -> None: ...
def set_resnet_unit_outputs(
    resnet_unit: Any, meanX: Any, varX: Any, meanZ: Optional[Any] = ..., varZ: Optional[Any] = ...
) -> None: ...
def fuse_resnet_unit(): ...
