from __future__ import annotations

from typing import Any, Optional

class AutoMixedPrecisionLists:
    white_list: Any = ...
    black_list: Any = ...
    gray_list: Any = ...
    unsupported_list: Any = ...
    black_varnames: Any = ...
    def __init__(
        self,
        custom_white_list: Optional[Any] = ...,
        custom_black_list: Optional[Any] = ...,
        custom_black_varnames: Optional[Any] = ...,
    ) -> None: ...

CustomOpLists = AutoMixedPrecisionLists
