from __future__ import annotations

from typing import Any, Optional

class StaticModelRunner:
    def __new__(cls, model_dir: Any, model_filename: Optional[Any] = ..., params_filename: Optional[Any] = ...): ...
