from __future__ import annotations

from typing import Any

age_table: Any
URL: str
MD5: str

class MovieInfo:
    index: Any = ...
    categories: Any = ...
    title: Any = ...
    def __init__(self, index: Any, categories: Any, title: Any) -> None: ...
    def value(self): ...

class UserInfo:
    index: Any = ...
    is_male: Any = ...
    age: Any = ...
    job_id: Any = ...
    def __init__(self, index: Any, gender: Any, age: Any, job_id: Any) -> None: ...
    def value(self): ...

MOVIE_INFO: Any
MOVIE_TITLE_DICT: Any
CATEGORIES_DICT: Any
USER_INFO: Any

def __initialize_meta_info__(): ...
def __reader__(rand_seed: int = ..., test_ratio: float = ..., is_test: bool = ...) -> None: ...
def __reader_creator__(**kwargs: Any): ...

train: Any
test: Any

def get_movie_title_dict(): ...
def __max_index_info__(a: Any, b: Any): ...
def max_movie_id(): ...
def max_user_id(): ...
def __max_job_id_impl__(a: Any, b: Any): ...
def max_job_id(): ...
def movie_categories(): ...
def user_info(): ...
def movie_info(): ...
def unittest() -> None: ...
def fetch() -> None: ...
