from __future__ import annotations

import unittest
from typing import Any

import paddle.fluid as fluid
from paddle.fluid.dygraph import nn as nn
from paddle.fluid.dygraph.io import INFER_MODEL_SUFFIX as INFER_MODEL_SUFFIX
from paddle.fluid.dygraph.io import INFER_PARAMS_SUFFIX as INFER_PARAMS_SUFFIX
from paddle.fluid.framework import IrGraph as IrGraph

def get_vaild_warning_num(warning: Any, w: Any): ...

class ImperativeLenet(fluid.dygraph.Layer):
    features: Any = ...
    fc: Any = ...
    def __init__(self, num_classes: int = ...) -> None: ...
    def forward(self, inputs: Any): ...

class TestImperativeOutSclae(unittest.TestCase):
    root_path: Any = ...
    param_save_path: Any = ...
    save_path: Any = ...
    def setUp(self) -> None: ...
    def tearDown(self) -> None: ...
    def func_out_scale_acc(self) -> None: ...
    def test_out_scale_acc(self) -> None: ...
