from __future__ import annotations

class PSMode:
    TRANSPILER: int = ...
    PSLIB: int = ...

class DistributedMode:
    SYNC: int = ...
    ASYNC: int = ...
    HALF_ASYNC: int = ...
    GEO: int = ...
