from __future__ import annotations

from typing import Any

from paddle.distributed.fleet import ascend_utils as ascend_utils
from paddle.distributed.fleet import cloud_utils as cloud_utils
from paddle.distributed.fleet import launch_utils as launch_utils
from paddle.distributed.fleet.elastic.manager import LauncherInterface
from paddle.distributed.fleet.launch_utils import *

class CollectiveLauncher(LauncherInterface):
    args: Any = ...
    procs: Any = ...
    def __init__(self, args: Any) -> None: ...
    tmp_dir: Any = ...
    def launch(self) -> None: ...
    def stop(self) -> None: ...
    def watch(self): ...
