from __future__ import annotations

from typing import Any

def kl_divergence(p: Any, q: Any): ...
def register_kl(cls_p: Any, cls_q: Any): ...

class _Compare:
    classes: Any = ...
    def __init__(self, *classes: Any) -> None: ...
    def __eq__(self, other: Any) -> Any: ...
    def __le__(self, other: Any) -> Any: ...
