from __future__ import annotations

from typing import Any

layer_name_map: Any
fake_quant_input_layers: Any
fake_quant_output_layers: Any
fake_quant_leaf_layers: Any
fake_quant_wrap_layers: Any
spec_channel_axis_layers: Any
weight_op_types: Any
fake_quantize_dequantize_op_types: Any

def load_variable_data(scope: Any, var_name: Any): ...
def find_previous_op(block: Any, var_name: Any): ...
def find_next_ops(block: Any, var_name: Any): ...
def find_parent_layer_and_sub_name(model: Any, name: Any): ...
def program_all_ops(program: Any): ...
def is_leaf_layer(layer: Any): ...
def fp_numpy_to_naive(x_np: Any): ...
