from __future__ import annotations

from typing import Any, Optional

def convert_float_to_uint16(in_list: Any): ...
def bf16_guard() -> None: ...
def cast_model_to_bf16(
    program: Any, startup_prog: Optional[Any] = ..., amp_lists: Optional[Any] = ..., use_bf16_guard: bool = ...
): ...
def cast_parameters_to_bf16(
    place: Any, program: Any, scope: Optional[Any] = ..., to_bf16_var_names: Optional[Any] = ...
) -> None: ...
def rewrite_program_bf16(main_prog: Any, amp_lists: Optional[Any] = ...) -> None: ...
