from __future__ import annotations

from typing import Any

from ....framework import IrNode as IrNode
from ....framework import Operator as Operator

def load_variable_data(scope: Any, var_name: Any): ...
def set_variable_data(scope: Any, place: Any, var_name: Any, np_value: Any) -> None: ...
def quant_tensor(x: Any, scale: Any, quant_axis: int = ..., weight_bits: int = ...): ...
def dequant_tensor(x: Any, scale: Any, quant_axis: int = ..., weight_bits: int = ...): ...
def bias_correction_w(x: Any, x_quant: Any, scale_v: Any, quant_axis: Any, weight_bits: int = ...): ...
def stable_sigmoid(x: Any): ...
def calculate_quant_cos_error(orig_tensor: Any, qdq_tensor: Any): ...

class tqdm:
    total: Any = ...
    bar_format: Any = ...
    ncols: Any = ...
    n: int = ...
    def __init__(self, total: Any, bar_format: str = ..., ncols: int = ...) -> None: ...
    def update(self, n: int = ...) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None: ...
