from __future__ import annotations

from .cifar import Cifar10 as Cifar10
from .cifar import Cifar100 as Cifar100
from .flowers import Flowers as Flowers
from .folder import DatasetFolder as DatasetFolder
from .folder import ImageFolder as ImageFolder
from .mnist import MNIST as MNIST
from .mnist import FashionMNIST as FashionMNIST
from .voc2012 import VOC2012 as VOC2012
