from __future__ import annotations

from typing import Any, Optional

def fft(x: Any, n: Optional[Any] = ..., axis: int = ..., norm: str = ..., name: Optional[Any] = ...): ...
def ifft(x: Any, n: Optional[Any] = ..., axis: int = ..., norm: str = ..., name: Optional[Any] = ...): ...
def rfft(x: Any, n: Optional[Any] = ..., axis: int = ..., norm: str = ..., name: Optional[Any] = ...): ...
def irfft(x: Any, n: Optional[Any] = ..., axis: int = ..., norm: str = ..., name: Optional[Any] = ...): ...
def hfft(x: Any, n: Optional[Any] = ..., axis: int = ..., norm: str = ..., name: Optional[Any] = ...): ...
def ihfft(x: Any, n: Optional[Any] = ..., axis: int = ..., norm: str = ..., name: Optional[Any] = ...): ...
def fftn(x: Any, s: Optional[Any] = ..., axes: Optional[Any] = ..., norm: str = ..., name: Optional[Any] = ...): ...
def ifftn(x: Any, s: Optional[Any] = ..., axes: Optional[Any] = ..., norm: str = ..., name: Optional[Any] = ...): ...
def rfftn(x: Any, s: Optional[Any] = ..., axes: Optional[Any] = ..., norm: str = ..., name: Optional[Any] = ...): ...
def irfftn(x: Any, s: Optional[Any] = ..., axes: Optional[Any] = ..., norm: str = ..., name: Optional[Any] = ...): ...
def hfftn(x: Any, s: Optional[Any] = ..., axes: Optional[Any] = ..., norm: str = ..., name: Optional[Any] = ...): ...
def ihfftn(x: Any, s: Optional[Any] = ..., axes: Optional[Any] = ..., norm: str = ..., name: Optional[Any] = ...): ...
def fft2(x: Any, s: Optional[Any] = ..., axes: Any = ..., norm: str = ..., name: Optional[Any] = ...): ...
def ifft2(x: Any, s: Optional[Any] = ..., axes: Any = ..., norm: str = ..., name: Optional[Any] = ...): ...
def rfft2(x: Any, s: Optional[Any] = ..., axes: Any = ..., norm: str = ..., name: Optional[Any] = ...): ...
def irfft2(x: Any, s: Optional[Any] = ..., axes: Any = ..., norm: str = ..., name: Optional[Any] = ...): ...
def hfft2(x: Any, s: Optional[Any] = ..., axes: Any = ..., norm: str = ..., name: Optional[Any] = ...): ...
def ihfft2(x: Any, s: Optional[Any] = ..., axes: Any = ..., norm: str = ..., name: Optional[Any] = ...): ...
def fftfreq(n: Any, d: float = ..., dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def rfftfreq(n: Any, d: float = ..., dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def fftshift(x: Any, axes: Optional[Any] = ..., name: Optional[Any] = ...): ...
def ifftshift(x: Any, axes: Optional[Any] = ..., name: Optional[Any] = ...): ...
