from __future__ import annotations

from typing import Any

class Server:
    def __init__(self) -> None: ...

class Worker:
    def __init__(self) -> None: ...

class DownpourServer(Server):
    server_: Any = ...
    def __init__(self) -> None: ...
    def add_sparse_table(self, table_id: Any, learning_rate: Any, slot_key_vars: Any, slot_value_var: Any) -> None: ...
    def add_dense_table(self, table_id: Any, learning_rate: Any, param_var: Any, grad_var: Any): ...
    def get_desc(self): ...

class DownpourWorker(Worker):
    window: Any = ...
    worker_: Any = ...
    def __init__(self, window: Any) -> None: ...
    def add_sparse_table(self, table_id: Any, learning_rate: Any, slot_key_vars: Any, slot_value_vars: Any) -> None: ...
    def add_dense_table(self, table_id: Any, learning_rate: Any, param_vars: Any, grad_vars: Any): ...
    def get_desc(self): ...
