from __future__ import annotations

from typing import Any

def seed(seed: Any): ...
def get_cuda_rng_state(): ...
def set_cuda_rng_state(state_list: Any) -> None: ...
def set_random_seed_generator(name: Any, seed: Any) -> None: ...
def get_random_seed_generator(name: Any): ...
