from __future__ import annotations

import unittest
from typing import Any

from imperative_test_utils import fix_model_dict as fix_model_dict

class TestImperativeQatAmp(unittest.TestCase):
    @classmethod
    def setUpClass(cls) -> None: ...
    @classmethod
    def tearDownClass(cls) -> None: ...
    def cache_unzipping(self, target_folder: Any, zip_path: Any) -> None: ...
    def download_model(self, data_url: Any, data_md5: Any, folder_name: Any): ...
    qat: Any = ...
    train_batch_num: int = ...
    train_batch_size: int = ...
    test_batch_num: int = ...
    test_batch_size: int = ...
    eval_acc_top1: float = ...
    def set_vars(self) -> None: ...
    def model_train(self, model: Any, batch_num: int = ..., batch_size: int = ..., use_amp: bool = ...) -> None: ...
    def model_test(self, model: Any, batch_num: int = ..., batch_size: int = ..., use_amp: bool = ...): ...
    def ptq(self) -> None: ...
    def test_ptq(self) -> None: ...
