from __future__ import annotations

from typing import Any

from paddle.fluid.framework import is_compiled_with_cinn as is_compiled_with_cinn
from paddle.fluid.framework import is_compiled_with_cuda as is_compiled_with_cuda
from paddle.fluid.framework import is_compiled_with_rocm as is_compiled_with_rocm

def is_compiled_with_npu(): ...
def is_compiled_with_ipu(): ...
def IPUPlace(): ...
def is_compiled_with_xpu(): ...
def XPUPlace(dev_id: Any): ...
def is_compiled_with_mlu(): ...
def MLUPlace(dev_id: Any): ...
def get_cudnn_version(): ...
def set_device(device: Any): ...
def get_device(): ...
def get_all_device_type(): ...
def get_all_custom_device_type(): ...
def get_available_device(): ...
def get_available_custom_device(): ...
