from __future__ import annotations

from typing import Any

class Storable:
    def get_state(self) -> None: ...
    def set_state(self, state: Any) -> None: ...
    def save(self, path: Any): ...
    def load(self, path: Any) -> None: ...
