from __future__ import annotations

from .math import segment_max as segment_max
from .math import segment_mean as segment_mean
from .math import segment_min as segment_min
from .math import segment_sum as segment_sum
