from __future__ import annotations

from typing import Any

class DataGenerator:
    batch_size_: int = ...
    def __init__(self) -> None: ...
    def set_batch(self, batch_size: Any) -> None: ...
    def run_from_memory(self) -> None: ...
    def run_from_stdin(self) -> None: ...
    def generate_sample(self, line: Any) -> None: ...
    def generate_batch(self, samples: Any): ...

class MultiSlotStringDataGenerator(DataGenerator): ...
class MultiSlotDataGenerator(DataGenerator): ...
