from __future__ import annotations

from typing import Any

def noam_decay(d_model: Any, warmup_steps: Any, learning_rate: float = ...): ...
def exponential_decay(learning_rate: Any, decay_steps: Any, decay_rate: Any, staircase: bool = ...): ...
def natural_exp_decay(learning_rate: Any, decay_steps: Any, decay_rate: Any, staircase: bool = ...): ...
def inverse_time_decay(learning_rate: Any, decay_steps: Any, decay_rate: Any, staircase: bool = ...): ...
def polynomial_decay(
    learning_rate: Any, decay_steps: Any, end_learning_rate: float = ..., power: float = ..., cycle: bool = ...
): ...
def piecewise_decay(boundaries: Any, values: Any): ...
def cosine_decay(learning_rate: Any, step_each_epoch: Any, epochs: Any): ...
def linear_lr_warmup(learning_rate: Any, warmup_steps: Any, start_lr: Any, end_lr: Any): ...
