from __future__ import annotations

import unittest

def conv_block(): ...

class TestGraph(unittest.TestCase):
    def graph_apis(self, use_cuda: bool = ..., for_ci: bool = ...) -> None: ...
    def test_graph_apis_cpu(self) -> None: ...
    def test_graph_apis_cuda(self) -> None: ...
