from __future__ import annotations

from typing import Any

def data_layer_not_check(name: Any, shape: Any, dtype: str = ..., lod_level: int = ...): ...
def to_static_variable_gast_node(name: Any): ...
def create_static_variable_gast_node(name: Any): ...
def create_fill_constant_node(name: Any, value: Any): ...
def to_static_variable(x: Any): ...
def create_bool_as_type(x: Any, value: bool = ...): ...
