from __future__ import annotations

from .base.distributed_strategy import DistributedStrategy as DistributedStrategy
from .base.fleet_base import Fleet as Fleet
from .base.role_maker import PaddleCloudRoleMaker as PaddleCloudRoleMaker
from .base.role_maker import Role as Role
from .base.role_maker import UserDefinedRoleMaker as UserDefinedRoleMaker
from .base.topology import CommunicateTopology as CommunicateTopology
from .base.topology import HybridCommunicateGroup as HybridCommunicateGroup
from .base.util_factory import UtilBase as UtilBase
from .data_generator.data_generator import (
    MultiSlotDataGenerator as MultiSlotDataGenerator,
)
from .data_generator.data_generator import (
    MultiSlotStringDataGenerator as MultiSlotStringDataGenerator,
)

rank_in_node = local_rank
