from __future__ import annotations

from typing import Any, Optional

def cuda_profiler(output_file: Any, output_mode: Optional[Any] = ..., config: Optional[Any] = ...) -> None: ...
def reset_profiler() -> None: ...
def start_profiler(state: Any, tracer_option: str = ...) -> None: ...
def stop_profiler(sorted_key: Optional[Any] = ..., profile_path: str = ...) -> None: ...
def profiler(
    state: Any, sorted_key: Optional[Any] = ..., profile_path: str = ..., tracer_option: str = ...
) -> None: ...
