from __future__ import annotations

from typing import Any

class JobMode:
    COLLECTIVE: str = ...
    PS: str = ...
    HETER: str = ...

class Job:
    def __init__(self, jid: str = ..., mode: Any = ..., nnodes: str = ...) -> None: ...
    @property
    def mode(self): ...
    @property
    def id(self): ...
    @property
    def elastic(self): ...
    @property
    def replicas(self): ...
    @property
    def replicas_min(self): ...
    @property
    def replicas_max(self): ...
    @replicas.setter
    def replicas(self, replicas: Any) -> None: ...
    def set_replicas(self, nnodes: str) -> Any: ...
