from __future__ import annotations

from typing import Any

DATA_URL: str
DATA_MD5: str
TOTAL_EN_WORDS: int
TOTAL_DE_WORDS: int
START_MARK: str
END_MARK: str
UNK_MARK: str

def reader_creator(tar_file: Any, file_name: Any, src_dict_size: Any, trg_dict_size: Any, src_lang: Any): ...
def train(src_dict_size: Any, trg_dict_size: Any, src_lang: str = ...): ...
def test(src_dict_size: Any, trg_dict_size: Any, src_lang: str = ...): ...
def validation(src_dict_size: Any, trg_dict_size: Any, src_lang: str = ...): ...
def get_dict(lang: Any, dict_size: Any, reverse: bool = ...): ...
def fetch() -> None: ...
