from __future__ import annotations

class Status:
    UNINIT: str = ...
    READY: str = ...
    RUNNING: str = ...
    FAILED: str = ...
    TERMINATING: str = ...
    RESTARTING: str = ...
    UNKNOWN: str = ...
    COMPLETED: str = ...
    DONE: str = ...
    def __init__(self) -> None: ...
    def current(self): ...
    def is_running(self): ...
    def is_restarting(self): ...
    def is_done(self): ...
    def run(self) -> None: ...
    def fail(self) -> None: ...
    def complete(self) -> None: ...
    def restart(self) -> None: ...
    def done(self) -> None: ...
