from __future__ import annotations

from test_imperative_qat import TestImperativeQat

class TestImperativeQatChannelWise(TestImperativeQat):
    weight_quantize_type: str = ...
    activation_quantize_type: str = ...
    diff_threshold: float = ...
    onnx_format: bool = ...
    fuse_conv_bn: bool = ...
    def set_vars(self) -> None: ...

class TestImperativeQatChannelWiseONNXFormat(TestImperativeQat):
    weight_quantize_type: str = ...
    activation_quantize_type: str = ...
    onnx_format: bool = ...
    diff_threshold: float = ...
    fuse_conv_bn: bool = ...
    def set_vars(self) -> None: ...
