from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

URL_DEV_TEST: str
MD5_DEV_TEST: str
URL_TRAIN: str
MD5_TRAIN: str
START: str
END: str
UNK: str
UNK_IDX: int

class WMT14(Dataset):
    mode: Any = ...
    data_file: Any = ...
    dict_size: Any = ...
    def __init__(
        self, data_file: Optional[Any] = ..., mode: str = ..., dict_size: int = ..., download: bool = ...
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...
    def get_dict(self, reverse: bool = ...): ...
