from __future__ import annotations

from typing import Any, Optional

class LayerOpsRecoder:
    start: Any = ...
    end: Any = ...
    ops: Any = ...
    is_valid: Any = ...
    hooks: Any = ...
    def __init__(
        self,
        start: int = ...,
        end: int = ...,
        ops: Optional[Any] = ...,
        is_valid: bool = ...,
        hooks: Optional[Any] = ...,
    ) -> None: ...

def record_program_ops_pre_hook(layer: Any, inputs: Any) -> None: ...
def set_op_customized_attrs_post_hook(layer: Any, inputs: Any, outputs: Any) -> None: ...
