# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['paddle-stubs']

package_data = \
{'': ['*'],
 'paddle-stubs': ['amp/*',
                  'autograd/*',
                  'cost_model/*',
                  'dataset/*',
                  'device/*',
                  'device/cuda/*',
                  'distributed/*',
                  'distributed/auto_parallel/*',
                  'distributed/auto_parallel/cost/*',
                  'distributed/auto_parallel/operators/*',
                  'distributed/auto_parallel/tuner/*',
                  'distributed/fleet/*',
                  'distributed/fleet/base/*',
                  'distributed/fleet/data_generator/*',
                  'distributed/fleet/dataset/*',
                  'distributed/fleet/elastic/*',
                  'distributed/fleet/meta_optimizers/*',
                  'distributed/fleet/meta_optimizers/ascend/*',
                  'distributed/fleet/meta_optimizers/dygraph_optimizer/*',
                  'distributed/fleet/meta_optimizers/sharding/*',
                  'distributed/fleet/meta_parallel/*',
                  'distributed/fleet/meta_parallel/parallel_layers/*',
                  'distributed/fleet/meta_parallel/pp_utils/*',
                  'distributed/fleet/meta_parallel/sharding/*',
                  'distributed/fleet/metrics/*',
                  'distributed/fleet/runtime/*',
                  'distributed/fleet/utils/*',
                  'distributed/launch/*',
                  'distributed/launch/context/*',
                  'distributed/launch/controllers/*',
                  'distributed/launch/job/*',
                  'distributed/launch/plugins/*',
                  'distributed/launch/utils/*',
                  'distributed/metric/*',
                  'distributed/models/*',
                  'distributed/models/moe/*',
                  'distributed/passes/*',
                  'distributed/ps/*',
                  'distributed/ps/utils/*',
                  'distributed/sharding/*',
                  'distribution/*',
                  'fluid/*',
                  'fluid/contrib/*',
                  'fluid/contrib/decoder/*',
                  'fluid/contrib/extend_optimizer/*',
                  'fluid/contrib/layers/*',
                  'fluid/contrib/mixed_precision/*',
                  'fluid/contrib/mixed_precision/bf16/*',
                  'fluid/contrib/quantize/*',
                  'fluid/contrib/slim/*',
                  'fluid/contrib/slim/quantization/*',
                  'fluid/contrib/slim/quantization/imperative/*',
                  'fluid/contrib/slim/tests/*',
                  'fluid/contrib/sparsity/*',
                  'fluid/dataloader/*',
                  'fluid/distributed/*',
                  'fluid/dygraph/*',
                  'fluid/dygraph/amp/*',
                  'fluid/dygraph/dygraph_to_static/*',
                  'fluid/incubate/*',
                  'fluid/incubate/checkpoint/*',
                  'fluid/incubate/data_generator/*',
                  'fluid/incubate/fleet/*',
                  'fluid/incubate/fleet/base/*',
                  'fluid/incubate/fleet/collective/*',
                  'fluid/incubate/fleet/parameter_server/*',
                  'fluid/incubate/fleet/parameter_server/distribute_transpiler/*',
                  'fluid/incubate/fleet/parameter_server/ir/*',
                  'fluid/incubate/fleet/parameter_server/pslib/*',
                  'fluid/incubate/fleet/utils/*',
                  'fluid/inference/*',
                  'fluid/layers/*',
                  'fluid/transpiler/*',
                  'fluid/transpiler/details/*',
                  'framework/*',
                  'hapi/*',
                  'incubate/*',
                  'incubate/autograd/*',
                  'incubate/checkpoint/*',
                  'incubate/multiprocessing/*',
                  'incubate/nn/*',
                  'incubate/nn/functional/*',
                  'incubate/nn/layer/*',
                  'incubate/operators/*',
                  'incubate/optimizer/*',
                  'incubate/optimizer/functional/*',
                  'incubate/passes/*',
                  'incubate/tensor/*',
                  'io/*',
                  'jit/*',
                  'jit/dy2static/*',
                  'libs/*',
                  'metric/*',
                  'nn/*',
                  'nn/functional/*',
                  'nn/initializer/*',
                  'nn/layer/*',
                  'nn/quant/*',
                  'nn/utils/*',
                  'onnx/*',
                  'optimizer/*',
                  'profiler/*',
                  'reader/*',
                  'reader/tests/*',
                  'sparse/*',
                  'sparse/functional/*',
                  'sparse/layer/*',
                  'static/*',
                  'static/amp/*',
                  'static/nn/*',
                  'static/sparsity/*',
                  'tensor/*',
                  'text/*',
                  'text/datasets/*',
                  'utils/*',
                  'utils/cpp_extension/*',
                  'utils/gast/*',
                  'vision/*',
                  'vision/datasets/*',
                  'vision/models/*',
                  'vision/transforms/*']}

install_requires = \
['paddlepaddle>=2.3.1,<3.0.0', 'typing-extensions>=4.3.0,<5.0.0']

setup_kwargs = {
    'name': 'paddlepaddle-stubs',
    'version': '2.3.1.dev0',
    'description': '',
    'long_description': 'None',
    'author': 'Nyakku Shigure',
    'author_email': 'sigure.qaq@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
