from __future__ import annotations

from typing import Any, Optional

class CUDAGraph:
    def __init__(self, place: Optional[Any] = ..., mode: str = ...) -> None: ...
    def capture_begin(self) -> None: ...
    def capture_end(self) -> None: ...
    def replay(self) -> None: ...
    def reset(self) -> None: ...
    def print_to_dot_files(self, dirname: Any, flags: Optional[Any] = ...) -> None: ...
