from __future__ import annotations

from typing import Any

DESCRIPTOR: Any
TableType: Any
PsCmdID: Any
PS_SPARSE_TABLE: int
PS_DENSE_TABLE: int
PS_PULL_DENSE_TABLE: int
PS_PUSH_DENSE_TABLE: int
PS_PULL_SPARSE_TABLE: int
PS_PUSH_SPARSE_TABLE: int
PS_SHRINK_TABLE: int
PS_SAVE_ONE_TABLE: int
PS_SAVE_ALL_TABLE: int
PS_LOAD_ONE_TABLE: int
PS_LOAD_ALL_TABLE: int
PS_CLEAR_ONE_TABLE: int
PS_CLEAR_ALL_TABLE: int
PS_PUSH_DENSE_PARAM: int
PS_STOP_SERVER: int
PS_SAVE_ONE_CACHE_TABLE: int
PS_GET_CACHE_THRESHOLD: int
PS_CACHE_SHUFFLE: int
PS_COPY_TABLE: int
PS_COPY_TABLE_BY_FEASIGN: int
PS_PULL_SPARSE_TABLE_WITH_DEPENDENCY: int
PS_PUSH_SPARSE_TABLE_WITH_DEPENDENCY: int
PS_PRINT_TABLE_STAT: int
PS_S2S_MSG: int
PSParameter: Any
WorkerParameter: Any
ServerParameter: Any
DownpourWorkerParameter: Any
DownpourTrainerParameter: Any
ProgramConfig: Any
DenseTableParameter: Any
SparseTableParameter: Any
DownpourServerParameter: Any
ServerServiceParameter: Any
TableParameter: Any
TableAccessorParameter: Any
DownpourTableAccessorParameter: Any
TableAccessorSaveParameter: Any
PsRequestMessage: Any
SparseSGDRuleParameter: Any
SparseCommonSGDRuleParameter: Any
SparseNaiveSGDRuleParameter: Any
SparseAdagradSGDRuleParameter: Any
SparseAdamSGDParameter: Any
DenseSGDRuleParameter: Any
AdamSGDParameter: Any
NaiveSGDParameter: Any
SummarySGDParameter: Any
MovingAverageRuleParameter: Any
PsResponseMessage: Any
FsClientParameter: Any
