from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

DATA_URL: str
DATA_MD5: str
WORDDICT_URL: str
WORDDICT_MD5: str
VERBDICT_URL: str
VERBDICT_MD5: str
TRGDICT_URL: str
TRGDICT_MD5: str
EMB_URL: str
EMB_MD5: str
UNK_IDX: int

class Conll05st(Dataset):
    data_file: Any = ...
    word_dict_file: Any = ...
    verb_dict_file: Any = ...
    target_dict_file: Any = ...
    emb_file: Any = ...
    word_dict: Any = ...
    predicate_dict: Any = ...
    label_dict: Any = ...
    def __init__(
        self,
        data_file: Optional[Any] = ...,
        word_dict_file: Optional[Any] = ...,
        verb_dict_file: Optional[Any] = ...,
        target_dict_file: Optional[Any] = ...,
        emb_file: Optional[Any] = ...,
        download: bool = ...,
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...
    def get_dict(self): ...
    def get_embedding(self): ...
