from __future__ import annotations

import unittest

from paddle.fluid.dygraph.container import Sequential as Sequential
from paddle.nn import Linear as Linear
from paddle.nn import Softmax as Softmax

class TestImperativeQat(unittest.TestCase):
    weight_quantize_type: str = ...
    activation_quantize_type: str = ...
    onnx_format: bool = ...
    check_export_model_accuracy: bool = ...
    diff_threshold: float = ...
    fuse_conv_bn: bool = ...
    def set_vars(self) -> None: ...
    def func_qat(self) -> None: ...
    def test_qat(self) -> None: ...

class TestImperativeQatONNXFormat(unittest.TestCase):
    weight_quantize_type: str = ...
    activation_quantize_type: str = ...
    onnx_format: bool = ...
    diff_threshold: float = ...
    fuse_conv_bn: bool = ...
    def set_vars(self) -> None: ...
