from __future__ import annotations

import collections
from typing import Any, Optional

from numpy import cos as cos
from numpy import sin as sin
from numpy import tan as tan

def to_tensor(pic: Any, data_format: str = ...): ...
def resize(img: Any, size: Any, interpolation: str = ...): ...
def pad(img: Any, padding: Any, fill: int = ..., padding_mode: str = ...): ...
def crop(img: Any, top: Any, left: Any, height: Any, width: Any): ...
def center_crop(img: Any, output_size: Any): ...
def hflip(img: Any): ...
def vflip(img: Any): ...
def adjust_brightness(img: Any, brightness_factor: Any): ...
def adjust_contrast(img: Any, contrast_factor: Any): ...
def adjust_saturation(img: Any, saturation_factor: Any): ...
def adjust_hue(img: Any, hue_factor: Any): ...
def rotate(
    img: Any, angle: Any, interpolation: str = ..., expand: bool = ..., center: Optional[Any] = ..., fill: int = ...
): ...
def to_grayscale(img: Any, num_output_channels: int = ...): ...
def normalize(img: Any, mean: Any, std: Any, data_format: str = ..., to_rgb: bool = ...): ...
