from __future__ import annotations

from typing import Any

from paddle.distribution import distribution

class Multinomial(distribution.Distribution):
    probs: Any = ...
    total_count: Any = ...
    def __init__(self, total_count: Any, probs: Any) -> None: ...
    @property
    def mean(self): ...
    @property
    def variance(self): ...
    def prob(self, value: Any): ...
    def log_prob(self, value: Any): ...
    def sample(self, shape: Any = ...): ...
    def entropy(self): ...
