from __future__ import annotations

from ast import AST
from typing import Any

from .ast3 import ast_to_gast as ast_to_gast
from .ast3 import gast_to_ast as gast_to_ast

class TypeIgnore(AST): ...

py_version: Any

def parse(*args: Any, **kwargs: Any): ...
def literal_eval(node_or_string: Any): ...
def get_docstring(node: Any, clean: bool = ...): ...
def copy_location(new_node: Any, old_node: Any): ...
def fix_missing_locations(node: Any): ...
def increment_lineno(node: Any, n: int = ...): ...
