from __future__ import annotations

from typing import Any

int_type = int
long_type = int

def to_text(obj: Any, encoding: str = ..., inplace: bool = ...): ...
def to_bytes(obj: Any, encoding: str = ..., inplace: bool = ...): ...
def round(x: Any, d: int = ...): ...
def floor_division(x: Any, y: Any): ...
def get_exception_message(exc: Any): ...
