from __future__ import annotations

from typing import Any, Optional

class ImperativePTQ:
    def __init__(self, quant_config: Any = ...) -> None: ...
    def quantize(self, model: Any, inplace: bool = ..., fuse: bool = ..., fuse_list: Optional[Any] = ...): ...
    def save_quantized_model(self, model: Any, path: Any, input_spec: Optional[Any] = ..., **config: Any) -> None: ...
