from __future__ import annotations

from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    create_bool_as_type as create_bool_as_type,
)
from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    create_fill_constant_node as create_fill_constant_node,
)
from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    create_static_variable_gast_node as create_static_variable_gast_node,
)
from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    data_layer_not_check as data_layer_not_check,
)
from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    to_static_variable as to_static_variable,
)
from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    to_static_variable_gast_node as to_static_variable_gast_node,
)
