from __future__ import annotations

from typing import Any, Optional

def set_image_backend(backend: Any) -> None: ...
def get_image_backend(): ...
def image_load(path: Any, backend: Optional[Any] = ...): ...
