from __future__ import annotations

from typing import Any

from ..fluid import core as core

def Singleton(cls): ...

class OpUpdateInfoHelper:
    def __init__(self, info: Any) -> None: ...
    def verify_key_value(self, name: str = ...): ...

class OpLastCheckpointChecker:
    raw_version_map: Any = ...
    checkpoints_map: Any = ...
    def __init__(self) -> None: ...
    def filter_updates(self, op_name: Any, type: Any = ..., key: str = ...): ...
