from __future__ import annotations

from typing import Any

class KVClient:
    endpoint: Any = ...
    def __init__(self, endpoint: str = ...) -> None: ...
    def put(self, key: Any, value: Any): ...
    def get(self, key: Any): ...
    def get_prefix(self, key: Any): ...
    def delete(self, key: Any): ...
    def wait_server_ready(self, timeout: int = ...): ...
