from __future__ import annotations

from typing import Any, Optional

HOME: Any
DATA_HOME: Any

def must_mkdirs(path: Any) -> None: ...
def md5file(fname: Any): ...
def download(url: Any, module_name: Any, md5sum: Any, save_name: Optional[Any] = ...): ...
def fetch_all() -> None: ...
def split(reader: Any, line_count: Any, suffix: str = ..., dumper: Any = ...) -> None: ...
def cluster_files_reader(files_pattern: Any, trainer_count: Any, trainer_id: Any, loader: Any = ...): ...
